﻿using PDF_Office.Model.Dialog.ToolsDialogs;
using Prism.Commands;
using Prism.Mvvm;
using Prism.Services.Dialogs;
using System;
using System.Collections.Generic;
using System.Diagnostics;
using System.Linq;
using System.Windows.Forms;
using Forms = System.Windows.Forms;
using System.Xml.Linq;
using ComPDFKit.PDFDocument;
using PDF_Office.Model;
using System.Threading.Tasks;
using DialogResult = Prism.Services.Dialogs.DialogResult;
using System.Windows.Controls;
using System.Windows;
using MessageBox = System.Windows.Forms.MessageBox;
using static System.Windows.Forms.VisualStyles.VisualStyleElement.Window;

namespace PDF_Office.ViewModels.Dialog.ToolsDialogs
{
    public class CompressDialogViewModel : BindableBase,IDialogAware
    {
        private CPDFDocument document;

        public IDialogService dialogs;

        public DelegateCommand LargeQualityCommand { get; set; }

        public DelegateCommand StandardQualityCommand { get; set; }

        public DelegateCommand LittleQualityCommand { get; set; }

        public DelegateCommand MicroQualityCommand { get; set; }

        public DelegateCommand CompressCommand { get; set; }

        public DelegateCommand ConfirmCompressCommand { get; set; }

        private Visibility _compressLargeStyle = Visibility.Hidden;
        public Visibility CompressLargeStyle
        {
            get { return _compressLargeStyle; }
            set
            {
                SetProperty(ref _compressLargeStyle, value);
            }
        }

        private Visibility _compressStandardStyle = Visibility.Hidden;
        public Visibility CompressStandardStyle
        {
            get { return _compressStandardStyle; }
            set
            {
                SetProperty(ref _compressStandardStyle, value);
            }
        }
        private Visibility _compressLittleStyle = Visibility.Hidden;
        public Visibility CompressLittleStyle
        {
            get { return _compressLittleStyle; }
            set
            {
                SetProperty(ref _compressLittleStyle, value);
            }
        }
        private Visibility _compressMicroStyle = Visibility.Hidden;
        public Visibility CompressMicroStyle
        {
            get { return _compressMicroStyle; }
            set
            {
                SetProperty(ref _compressMicroStyle, value);
            }
        }

        private CPDFDocument.GetPageIndexDelegate indexDelegate = null;

        CompressDialogModel compressDialogModel { get; set; }

        private IntPtr compressingIntpr = IntPtr.Zero;

        public CompressDialogViewModel(IDialogService dialogService)
        {
            LargeQualityCommand = new DelegateCommand(LargeQuality);
            StandardQualityCommand = new DelegateCommand(StandardQuality);
            LittleQualityCommand = new DelegateCommand(LittleQuality);
            MicroQualityCommand = new DelegateCommand(MicroQuality);
            CompressCommand = new DelegateCommand(Compress);
            ConfirmCompressCommand = new DelegateCommand(ConfirmCompress);
            dialogs = dialogService;
        }

        private void LargeQuality() {
            compressDialogModel.CompressQuality=CompressDialogModel.qualityLevel._large;
            CompressLargeStyle = Visibility.Visible;
            CompressStandardStyle = Visibility.Hidden;
            CompressLittleStyle = Visibility.Hidden;
            CompressMicroStyle = Visibility.Hidden;
        }
        private void StandardQuality()
        {
            compressDialogModel.CompressQuality =CompressDialogModel.qualityLevel._standard;
            CompressLargeStyle = Visibility.Hidden;
            CompressStandardStyle = Visibility.Visible;
            CompressLittleStyle = Visibility.Hidden;
            CompressMicroStyle = Visibility.Hidden;
        }
        private void LittleQuality()
        {
            compressDialogModel.CompressQuality = CompressDialogModel.qualityLevel._little;
            CompressLargeStyle = Visibility.Hidden;
            CompressStandardStyle = Visibility.Hidden;
            CompressLittleStyle = Visibility.Visible;
            CompressMicroStyle = Visibility.Hidden;
        }
        private void MicroQuality()
        {
            compressDialogModel.CompressQuality = CompressDialogModel.qualityLevel._micro;
            CompressLargeStyle = Visibility.Hidden;
            CompressStandardStyle = Visibility.Hidden;
            CompressLittleStyle = Visibility.Hidden;
            CompressMicroStyle = Visibility.Visible;
        }

        private void ConfirmCompress()
        {
            RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
        }

        private int GetIndex(int pageindex)
        {
            Trace.WriteLine(pageindex);
            return 0;
        }
        private async void  Compress() {

            FolderBrowserDialog folderDialog = new FolderBrowserDialog();
            Forms.SaveFileDialog sfd = new Forms.SaveFileDialog();
            /*
             *设置这个对话框的起始保存路径
             */
            sfd.InitialDirectory = document.FilePath;
            /*
             *设置保存的文件的类型，注意过滤器的语法 例子：“文件类型|*.后缀名；*.后缀名；”
             */
            sfd.Filter = "PDF|*.pdf;";
            /*
             *调用ShowDialog()方法显示该对话框，该方法的返回值代表用户是否点击了确定按钮
             **/
            sfd.FileName = document.FileName + "_CompressFile.pdf";
            if (sfd.ShowDialog() == Forms.DialogResult.OK)
            {
                /*
                 * 做一些工作
                 */
                
                Trace.WriteLine("compressDialogModel.CompressQuality:  " + compressDialogModel.CompressQuality);
                DialogParameters value = new DialogParameters();
                value.Add(ParameterNames.PDFDocument,document );
                value.Add(ParameterNames.FilePath, sfd.FileName);
                value.Add("compressDialogModel.CompressQuality", (int)compressDialogModel.CompressQuality);
                RequestClose?.Invoke(new DialogResult(ButtonResult.OK));
                dialogs.ShowDialog(DialogNames.ToolsProgressBarDialog, value, e => {

                });
                
                
                
            }
            else
            {
                MessageBox.Show("Cancel.");
            }

        }
        public string Title => "";

        public event Action<IDialogResult> RequestClose;

        public bool CanCloseDialog()
        {
            return true;
        }

        public void OnDialogClosed()
        {
        }

        public void OnDialogOpened(IDialogParameters parameters)
        {
            CPDFDocument doc = null;
            parameters.TryGetValue<CPDFDocument>(ParameterNames.PDFDocument, out doc);
            if (doc != null)
            {
                 CompressDialogModel compressdialogmodel =new CompressDialogModel();
                 document = doc;
                 compressDialogModel = compressdialogmodel;
                 compressDialogModel.CompressQuality =CompressDialogModel.qualityLevel._default;
            }
        }
    }
}
